---
Summary: `sbl` relative file path output only
Status: Done
---

# Description

We want to be able to just list the paths of all the cards that `sbl` returns when `sbl -b` or `sbl --bare` is called. The idea is that you'll be able to call

```
vim `sbl scrum1`
```

and be able to run the whole stand up going through the cards. Ordering the cards is a future goal.

We want to add the `_path` field as well, so it can be used in other queries.

# Depends

[[cli004]]

# Cucumber

**GIVEN** a collection of cards
**WHEN** `sbl` is called with the `-b` or `--bare` parameter
**THEN** the paths of all cards in the collection are returned with no other data - including no headers.

**GIVEN** a column configuration including the `_path` field
**WHEN** `sbl` is called
**THEN** then the path of the card is shown

# Implementation note

No unit test exists for this actual output yet. I'm not really happy enough with output to test for it.
